@@ -121,7 +121,6 @@ class RepositoryTester(unittest2.TestCase):
         self.test_repo.windows_path = test_value
         self.assertEqual(self.test_repo.windows_path, test_value)
 
-
     def test_windows_path_attribute_finishes_with_a_slash(self):
         """testing if the windows_path attribute will be finished with a slash
         even it is not supplied by default
@@ -161,7 +160,6 @@ class RepositoryTester(unittest2.TestCase):
         self.test_repo.osx_path = test_value
         self.assertEqual(self.test_repo.osx_path, test_value)
 
-
     def test_osx_path_attribute_finishes_with_a_slash(self):
         """testing if the osx_path attribute will be finished with a slash
         even it is not supplied by default
@@ -307,8 +305,10 @@ class RepositoryTester(unittest2.TestCase):
         """
         self.test_repo.windows_path = 'T:/Stalker_Projects'
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
-        test_windows_path = 'T:/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_windows_path = 'T:/Stalker_Projects/Sero/Task1/Task2/' \
+                            'Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
         self.assertEqual(
             self.test_repo.to_linux_path(test_windows_path),
             test_linux_path
@@ -319,7 +319,8 @@ class RepositoryTester(unittest2.TestCase):
         linux path
         """
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
         self.assertEqual(
             self.test_repo.to_linux_path(test_linux_path),
             test_linux_path
@@ -331,8 +332,10 @@ class RepositoryTester(unittest2.TestCase):
         """
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/' \
+                        'Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
         self.assertEqual(
             self.test_repo.to_linux_path(test_osx_path),
             test_linux_path
@@ -344,8 +347,10 @@ class RepositoryTester(unittest2.TestCase):
         """
         self.test_repo.windows_path = 'T:/Stalker_Projects'
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_windows_path_reverse = 'T:\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
+        test_windows_path_reverse = 'T:\\Stalker_Projects\\Sero\\Task1\\' \
+                                    'Task2\\Some_file.ma'
         self.assertEqual(
             self.test_repo.to_linux_path(test_windows_path_reverse),
             test_linux_path
@@ -356,8 +361,10 @@ class RepositoryTester(unittest2.TestCase):
         reverse linux path
         """
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_linux_path_reverse = '\\mnt\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
+        test_linux_path_reverse = '\\mnt\\T\\Stalker_Projects\\Sero\\Task1\\' \
+                                  'Task2\\Some_file.ma'
         self.assertEqual(
             self.test_repo.to_linux_path(test_linux_path_reverse),
             test_linux_path
@@ -369,8 +376,10 @@ class RepositoryTester(unittest2.TestCase):
         """
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_osx_path_reverse = '\\Volumes\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
+        test_osx_path_reverse = '\\Volumes\\T\\Stalker_Projects\\Sero\\' \
+                                'Task1\\Task2\\Some_file.ma'
         self.assertEqual(
             self.test_repo.to_linux_path(test_osx_path_reverse),
             test_linux_path
@@ -403,7 +412,8 @@ class RepositoryTester(unittest2.TestCase):
         """
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
         self.test_repo.windows_path = 'T:/Stalker_Projects'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
         test_windows_path = 'T:/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
         self.assertEqual(
             self.test_repo.to_windows_path(test_linux_path),
@@ -416,7 +426,8 @@ class RepositoryTester(unittest2.TestCase):
         """
         self.test_repo.windows_path = 'T:/Stalker_Projects'
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/' \
+                        'Some_file.ma'
         test_windows_path = 'T:/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
         self.assertEqual(
             self.test_repo.to_windows_path(test_osx_path),
@@ -429,7 +440,8 @@ class RepositoryTester(unittest2.TestCase):
         """
         self.test_repo.windows_path = 'T:/Stalker_Projects'
         test_windows_path = 'T:/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_windows_path_reverse = 'T:\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_windows_path_reverse = 'T:\\Stalker_Projects\\Sero\\Task1\\' \
+                                    'Task2\\Some_file.ma'
         self.assertEqual(
             self.test_repo.to_windows_path(test_windows_path_reverse),
             test_windows_path
@@ -442,7 +454,8 @@ class RepositoryTester(unittest2.TestCase):
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
         self.test_repo.windows_path = 'T:/Stalker_Projects'
         test_windows_path = 'T:/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_linux_path_reverse = '\\mnt\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_linux_path_reverse = '\\mnt\\T\\Stalker_Projects\\Sero\\Task1\\' \
+                                  'Task2\\Some_file.ma'
         self.assertEqual(
             self.test_repo.to_windows_path(test_linux_path_reverse),
             test_windows_path
@@ -455,7 +468,8 @@ class RepositoryTester(unittest2.TestCase):
         self.test_repo.windows_path = 'T:/Stalker_Projects'
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
         test_windows_path = 'T:/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_osx_path_reverse = '\\Volumes\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_osx_path_reverse = '\\Volumes\\T\\Stalker_Projects\\Sero\\' \
+                                'Task1\\Task2\\Some_file.ma'
         self.assertEqual(
             self.test_repo.to_windows_path(test_osx_path_reverse),
             test_windows_path
@@ -478,7 +492,8 @@ class RepositoryTester(unittest2.TestCase):
         self.test_repo.windows_path = 'T:/Stalker_Projects'
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
         test_windows_path = 'T:/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/' \
+                        'Some_file.ma'
         self.assertEqual(
             self.test_repo.to_osx_path(test_windows_path),
             test_osx_path
@@ -490,8 +505,10 @@ class RepositoryTester(unittest2.TestCase):
         """
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
+        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/' \
+                        'Some_file.ma'
         self.assertEqual(
             self.test_repo.to_osx_path(test_linux_path),
             test_osx_path
@@ -502,7 +519,8 @@ class RepositoryTester(unittest2.TestCase):
         osx path
         """
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/' \
+                        'Some_file.ma'
         self.assertEqual(
             self.test_repo.to_osx_path(test_osx_path),
             test_osx_path
@@ -514,8 +532,10 @@ class RepositoryTester(unittest2.TestCase):
         """
         self.test_repo.windows_path = 'T:/Stalker_Projects'
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_windows_path_reverse = 'T:\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/' \
+                        'Some_file.ma'
+        test_windows_path_reverse = 'T:\\Stalker_Projects\\Sero\\Task1\\' \
+                                    'Task2\\Some_file.ma'
         self.assertEqual(
             self.test_repo.to_osx_path(test_windows_path_reverse),
             test_osx_path
@@ -527,8 +547,10 @@ class RepositoryTester(unittest2.TestCase):
         """
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_linux_path_reverse = '\\mnt\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/' \
+                        'Some_file.ma'
+        test_linux_path_reverse = '\\mnt\\T\\Stalker_Projects\\Sero\\Task1\\' \
+                                  'Task2\\Some_file.ma'
         self.assertEqual(
             self.test_repo.to_osx_path(test_linux_path_reverse),
             test_osx_path
@@ -539,28 +561,36 @@ class RepositoryTester(unittest2.TestCase):
         reverse osx path
         """
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_osx_path_reverse = '\\Volumes\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/' \
+                        'Some_file.ma'
+        test_osx_path_reverse = '\\Volumes\\T\\Stalker_Projects\\Sero\\' \
+                                'Task1\\Task2\\Some_file.ma'
         self.assertEqual(
             self.test_repo.to_osx_path(test_osx_path_reverse),
             test_osx_path
         )
 
     def test_to_osx_path_returns_the_osx_version_of_the_given_path(self):
-        """testing if the to_windows_path returns the osx version of the
+        """testing if the to_osx_path returns the osx version of the
         given path
         """
         self.test_repo.windows_path = 'T:/Stalker_Projects'
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
 
-        test_windows_path = 'T:/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_windows_path = 'T:/Stalker_Projects/Sero/Task1/Task2/' \
+                            'Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
+        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/' \
+                        'Some_file.ma'
 
-        test_windows_path_reverse = 'T:\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
-        test_linux_path_reverse = '\\mnt\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
-        test_osx_path_reverse = '\\Volumes\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_windows_path_reverse = 'T:\\Stalker_Projects\\Sero\\Task1\\' \
+                                    'Task2\\Some_file.ma'
+        test_linux_path_reverse = '\\mnt\\T\\Stalker_Projects\\Sero\\Task1\\' \
+                                  'Task2\\Some_file.ma'
+        test_osx_path_reverse = '\\Volumes\\T\\Stalker_Projects\\Sero\\' \
+                                'Task1\\Task2\\Some_file.ma'
 
         self.assertEqual(
             self.test_repo.to_osx_path(test_windows_path),
@@ -592,59 +622,6 @@ class RepositoryTester(unittest2.TestCase):
             test_osx_path
         )
 
-
-    def test_to_osx_path_returns_the_osx_version_of_the_given_path(self):
-        """testing if the to_windows_path returns the osx version of the
-        given path
-        """
-        self.test_repo.windows_path = 'T:/Stalker_Projects'
-        self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
-        self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-
-        test_windows_path = 'T:/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-
-        test_windows_path_reverse = 'T:\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
-        test_linux_path_reverse = '\\mnt\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
-        test_osx_path_reverse = '\\Volumes\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
-
-        self.assertEqual(
-            self.test_repo.to_osx_path(test_windows_path),
-            test_osx_path
-        )
-
-        self.assertEqual(
-            self.test_repo.to_osx_path(test_linux_path),
-            test_osx_path
-        )
-
-        self.assertEqual(
-            self.test_repo.to_osx_path(test_osx_path),
-            test_osx_path
-        )
-
-        self.assertEqual(
-            self.test_repo.to_osx_path(test_windows_path_reverse),
-            test_osx_path
-        )
-
-        self.assertEqual(
-            self.test_repo.to_osx_path(test_linux_path_reverse),
-            test_osx_path
-        )
-
-        self.assertEqual(
-            self.test_repo.to_osx_path(test_osx_path_reverse),
-            test_osx_path
-        )
-
-
-
-
-
-
-
     def test_to_osx_path_raises_TypeError_if_path_is_None(self):
         """testing if to_osx_path raises TypeError if path is None
         """
@@ -655,27 +632,39 @@ class RepositoryTester(unittest2.TestCase):
         """
         self.assertRaises(TypeError, self.test_repo.to_osx_path, 123)
 
-    @unittest2.skipUnless(platform.system() == "Linux", "requires Linux")
     def test_to_native_path_returns_the_native_version_of_the_given_linux_path(self):
         """testing if the to_native_path returns the native version of the
         given linux path
         """
+        m1 = mocker.Mocker()
+        o = m1.replace(platform.system)
+        o()
+        m1.result("Linux")
+        m1.replay()
+
         self.test_repo.windows_path = 'T:/Stalker_Projects'
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
 
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
 
         self.assertEqual(
             self.test_repo.to_native_path(test_linux_path),
             test_linux_path
         )
+        m1.restore()
 
-    @unittest2.skipUnless(platform.system() == "Linux", "requires Linux")
     def test_to_native_path_returns_the_native_version_of_the_given_windows_path(self):
         """testing if the to_native_path returns the native version of the
         given windows path
         """
+        m1 = mocker.Mocker()
+        o = m1.replace(platform.system)
+        o()
+        m1.result("Linux")
+        m1.replay()
+
         self.test_repo.windows_path = 'T:/Stalker_Projects'
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
@@ -686,61 +675,94 @@ class RepositoryTester(unittest2.TestCase):
             self.test_repo.to_native_path(test_windows_path),
             '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
         )
+        m1.restore()
 
-    @unittest2.skipUnless(platform.system() == "Linux", "requires Linux")
     def test_to_native_path_returns_the_native_version_of_the_given_osx_path(self):
         """testing if the to_native_path returns the native version of the
         given osx path
         """
+        m1 = mocker.Mocker()
+        o = m1.replace(platform.system)
+        o()
+        m1.result("Linux")
+        m1.replay()
+
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
+        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/' \
+                        'Some_file.ma'
         self.assertEqual(
             self.test_repo.to_native_path(test_osx_path),
             test_linux_path
         )
+        m1.restore()
 
-    @unittest2.skipUnless(platform.system() == "Linux", "requires Linux")
     def test_to_native_path_returns_the_native_version_of_the_given_reverse_windows_path(self):
         """testing if the to_native_path returns the native version of the
         given reverse windows path
         """
+        m1 = mocker.Mocker()
+        o = m1.replace(platform.system)
+        o()
+        m1.result("Linux")
+        m1.replay()
+
         self.test_repo.windows_path = 'T:/Stalker_Projects'
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
-        test_windows_path_reverse = 'T:\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_windows_path_reverse = 'T:\\Stalker_Projects\\Sero\\Task1\\' \
+                                    'Task2\\Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
         self.assertEqual(
             self.test_repo.to_native_path(test_windows_path_reverse),
             test_linux_path
         )
+        m1.restore()
 
-    @unittest2.skipUnless(platform.system() == "Linux", "requires Linux")
     def test_to_native_path_returns_the_native_version_of_the_given_reverse_linux_path(self):
         """testing if the to_native_path returns the native version of the
         given reverse linux path
         """
+        m1 = mocker.Mocker()
+        o = m1.replace(platform.system)
+        o()
+        m1.result("Linux")
+        m1.replay()
+
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_linux_path_reverse = '\\mnt\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
+        test_linux_path_reverse = '\\mnt\\T\\Stalker_Projects\\Sero\\Task1\\' \
+                                  'Task2\\Some_file.ma'
         self.assertEqual(
             self.test_repo.to_native_path(test_linux_path_reverse),
             test_linux_path
         )
+        m1.restore()
 
-    @unittest2.skipUnless(platform.system() == "Linux", "requires Linux")
     def test_to_native_path_returns_the_native_version_of_the_given_reverse_osx_path(self):
         """testing if the to_native_path returns the native version of the
         given reverse osx path
         """
+        m1 = mocker.Mocker()
+        o = m1.replace(platform.system)
+        o()
+        m1.result("Linux")
+        m1.replay()
+
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
-        test_osx_path_reverse = '\\Volumes\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
+        test_osx_path_reverse = '\\Volumes\\T\\Stalker_Projects\\Sero\\' \
+                                'Task1\\Task2\\Some_file.ma'
         self.assertEqual(
             self.test_repo.to_native_path(test_osx_path_reverse),
             test_linux_path
         )
+        m1.restore()
 
     def test_to_native_path_raises_TypeError_if_path_is_None(self):
         """testing if to_native_path raises TypeError if path is None
@@ -757,7 +779,8 @@ class RepositoryTester(unittest2.TestCase):
         this repo or False otherwise
         """
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
-        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_linux_path = '/mnt/T/Stalker_Projects/Sero/Task1/Task2/' \
+                          'Some_file.ma'
         self.assertTrue(self.test_repo.is_in_repo(test_linux_path))
 
     def test_is_in_repo_returns_True_if_the_given_linux_reverse_path_is_in_this_repo(self):
@@ -765,7 +788,8 @@ class RepositoryTester(unittest2.TestCase):
         is in this repo or False otherwise
         """
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
-        test_linux_path_reverse = '\\mnt\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_linux_path_reverse = '\\mnt\\T\\Stalker_Projects\\Sero\\Task1\\' \
+                                  'Task2\\Some_file.ma'
         self.assertTrue(self.test_repo.is_in_repo(test_linux_path_reverse))
 
     def test_is_in_repo_returns_False_if_the_given_linux_path_is_not_in_this_repo(self):
@@ -773,8 +797,10 @@ class RepositoryTester(unittest2.TestCase):
         in this repo or False otherwise
         """
         self.test_repo.linux_path = '/mnt/T/Stalker_Projects'
-        test_not_in_path_linux_path = '/mnt/T/Other_Projects/Sero/Task1/Task2/Some_file.ma'
-        self.assertFalse(self.test_repo.is_in_repo(test_not_in_path_linux_path))
+        test_not_in_path_linux_path = '/mnt/T/Other_Projects/Sero/Task1/' \
+                                      'Task2/Some_file.ma'
+        self.assertFalse(
+            self.test_repo.is_in_repo(test_not_in_path_linux_path))
 
     def test_is_in_repo_returns_True_if_the_given_windows_path_is_in_this_repo(self):
         """testing if is_in_repo returns True if the given windows path is in
@@ -789,7 +815,8 @@ class RepositoryTester(unittest2.TestCase):
         is in this repo or False otherwise
         """
         self.test_repo.windows_path = 'T:/Stalker_Projects'
-        test_windows_path_reverse = 'T:\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_windows_path_reverse = 'T:\\Stalker_Projects\\Sero\\Task1\\' \
+                                    'Task2\\Some_file.ma'
         self.assertTrue(self.test_repo.is_in_repo(test_windows_path_reverse))
 
     def test_is_in_repo_returns_False_if_the_given_windows_path_is_not_in_this_repo(self):
@@ -797,15 +824,18 @@ class RepositoryTester(unittest2.TestCase):
         in this repo or False otherwise
         """
         self.test_repo.windows_path = 'T:/Stalker_Projects'
-        test_not_in_path_windows_path = 'T:/Other_Projects/Sero/Task1/Task2/Some_file.ma'
-        self.assertFalse(self.test_repo.is_in_repo(test_not_in_path_windows_path))
+        test_not_in_path_windows_path = 'T:/Other_Projects/Sero/Task1/Task2/' \
+                                        'Some_file.ma'
+        self.assertFalse(
+            self.test_repo.is_in_repo(test_not_in_path_windows_path))
 
     def test_is_in_repo_returns_True_if_the_given_osx_path_is_in_this_repo(self):
         """testing if is_in_repo returns True if the given osx path is in
         this repo or False otherwise
         """
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_osx_path = '/Volumes/T/Stalker_Projects/Sero/Task1/Task2/' \
+                        'Some_file.ma'
         self.assertTrue(self.test_repo.is_in_repo(test_osx_path))
 
     def test_is_in_repo_returns_True_if_the_given_osx_reverse_path_is_in_this_repo(self):
@@ -813,7 +843,8 @@ class RepositoryTester(unittest2.TestCase):
         is in this repo or False otherwise
         """
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-        test_osx_path_reverse = '\\Volumes\\T\\Stalker_Projects\\Sero\\Task1\\Task2\\Some_file.ma'
+        test_osx_path_reverse = '\\Volumes\\T\\Stalker_Projects\\Sero\\' \
+                                'Task1\\Task2\\Some_file.ma'
         self.assertTrue(self.test_repo.is_in_repo(test_osx_path_reverse))
 
     def test_is_in_repo_returns_False_if_the_given_osx_path_is_not_in_this_repo(self):
@@ -821,7 +852,8 @@ class RepositoryTester(unittest2.TestCase):
         in this repo or False otherwise
         """
         self.test_repo.osx_path = '/Volumes/T/Stalker_Projects'
-        test_not_in_path_osx_path = '/Volumes/T/Other_Projects/Sero/Task1/Task2/Some_file.ma'
+        test_not_in_path_osx_path = '/Volumes/T/Other_Projects/Sero/Task1/' \
+                                    'Task2/Some_file.ma'
         self.assertFalse(self.test_repo.is_in_repo(test_not_in_path_osx_path))
 
 
